#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : hailuo
# @Time         : 2024/12/6 09:05
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  :
import os

import logfire

from meutils.pipe import *
from meutils.async_utils import async_to_sync_pro

from meutils.async_task import dramatiq
from meutils.apis.hailuoai.openai_videos import SoraVideoRequest, Tasks

logfire.configure(token=os.getenv("LOGFIRE_TOKEN_TASKS"))


@dramatiq.actor()
@async_to_sync_pro
async def create_task(request: SoraVideoRequest, **kwargs):
    token = "eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJleHAiOjE3NzU3NDU3NTksInVzZXIiOnsiaWQiOiI0ODQxNjM2NzE3MDE4MzE2ODgiLCJuYW1lIjoi5p2wIOiigSIsImF2YXRhciI6IiIsImRldmljZUlEIjoiMzAyODMzNzU5NTEyNzY0NDE3IiwiaXNBbm9ueW1vdXMiOmZhbHNlfX0.U3oQESgf7qReJ_18WbP5FiGhzrl-eBCaw5K3K6nQD28"

    response = await Tasks(api_key=token).create(request)
    return response


if __name__ == '__main__':
    request = SoraVideoRequest()
    result = create_task(request)
    print(result)


#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : common
# @Time         : 2024/11/28 15:28
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  : 

from meutils.pipe import *
from meutils.decorators.retry import retrying

import dramatiq
from dramatiq.middleware import AsyncIO
from dramatiq.brokers.redis import RedisBroker  # 如果你用 RabbitMQ 就换成 RabbitmqBroker

from dramatiq.encoder import JSONEncoder

class PydanticJSONEncoder(JSONEncoder):
    def default(self, obj):
        if isinstance(obj, BaseModel):
            return obj.model_dump() # 或者 model_dump_json()
        return super().default(obj)



encoder = PydanticJSONEncoder()
broker = RedisBroker(url="redis://localhost:6379/0", encoder=encoder)
dramatiq.set_broker(broker)